.. _explanation:

Explanation
***********

As Charmcraft is a part of the `Juju Charm SDK <https://juju.is/docs/sdk>`_, most
explanation is hosted on the `Charm SDK docs <https://juju.is/docs/sdk/explanation>`_.

.. toctree::
   :maxdepth: 1


`Charm SDK docs <https://juju.is/docs/sdk/explanation>`_
========================================================
